@@ -1,9 +1,11 @@
 """
 Test tools for using formprocess handlers.
 """
+import unittest
+
 from webob.multidict import MultiDict
-from pepperedform.handler import (set_closed, prepare_for_peppercorn,
-        parse_with_peppercorn)
+
+from pepperedform.handler import parse_with_peppercorn, renderer_state_injector
 
 
 class DummyHandler(object):
@@ -14,17 +16,12 @@ class DummyState(object):
     pass
 
 
-class TestHandlerTools(object):
-        
-    def test_set_closed(self):
-        hook = set_closed(True)
-        handler = DummyHandler()
-        state = DummyState()
-        fill_kwargs = {}
-        errors = {}
-        defaults = {}
-        new_fill_kwargs = hook(handler, defaults, errors, state, fill_kwargs)
-        assert new_fill_kwargs['closed']
+class DummyFormRenderer(object):
+    def form_renderer_state(self, *args, **kwargs):
+        return dict(args=args, kwarg=kwargs)
+
+
+class TestHandlerTools(unittest.TestCase):
 
     def test_parse_for_peppercorn(self):
         handler = DummyHandler()
@@ -42,15 +39,13 @@ class TestHandlerTools(object):
             ('__end__', 'day:sequence'),
             ('__end__', 'days:sequence')])
         new_defaults = parse_with_peppercorn(handler, unsafe_params, state)
-        assert len(new_defaults['days']) == 3
+        self.assertEqual(len(new_defaults['days']), 3)
 
-    def test_prepare_for_peppercorn(self):
-        handler = DummyHandler()
-        state = DummyState()
+    def test_renderer_state_injector(self):
+        form_renderer = DummyFormRenderer()
+        injector = renderer_state_injector(form_renderer, inject_at_key='test')
+        fill_kwargs = {}
         defaults = {}
         errors = {}
-        fill_kwargs = {}
-        new_fill_kwargs = prepare_for_peppercorn(handler, defaults, errors, state,
-                fill_kwargs)
-        assert new_fill_kwargs.get('id_stack') == [], 'id_stack must be empty list'
-        assert new_fill_kwargs.get('getter'), 'getter must be defined'
+        fill_kwargs = injector(None, defaults, errors, None, fill_kwargs)
+        self.assertEqual(fill_kwargs['test']['args'], (defaults, errors))
